Skip site navigation (1)Skip section navigation (2)
Date:      Thu, 20 Dec 2001 08:14:07 -0800 (PST)
From:      Willem van Engen <wvengen@stack.nl>
To:        freebsd-gnats-submit@FreeBSD.org
Subject:   ports/33030: Port fix: sword, patches didn't get there
Message-ID:  <200112201614.fBKGE7m15444@freefall.freebsd.org>

next in thread | raw e-mail | index | archive | help

>Number:         33030
>Category:       ports
>Synopsis:       Port fix: sword, patches didn't get there
>Confidential:   no
>Severity:       non-critical
>Priority:       medium
>Responsible:    freebsd-ports
>State:          open
>Quarter:        
>Keywords:       
>Date-Required:
>Class:          change-request
>Submitter-Id:   current-users
>Arrival-Date:   Thu Dec 20 08:20:01 PST 2001
>Closed-Date:
>Last-Modified:
>Originator:     Willem van Engen
>Release:        
>Organization:
>Environment:
>Description:
Somehow the new patches didn't make it into the previous update, so here they are.
>How-To-Repeat:
      
>Fix:
diff -ruN misc/sword/files/patch-Makefile.cfg misc.new/sword/files/patch-Makefile.cfg
--- misc/sword/files/patch-Makefile.cfg	Thu Dec 13 03:53:57 2001
+++ misc.new/sword/files/patch-Makefile.cfg	Wed Dec 12 02:00:36 2001
@@ -1,6 +1,12 @@
---- Makefile.cfg.orig	Thu Dec 13 10:44:49 2001
-+++ Makefile.cfg	Thu Dec 13 10:47:07 2001
-@@ -6,7 +6,7 @@
+--- Makefile.cfg.orig	Wed Dec 12 00:56:50 2001
++++ Makefile.cfg	Wed Dec 12 00:57:18 2001
+@@ -1,4 +1,5 @@
+ # General defines
++include ${root}/localport.cfg
+ 
+ version := 1.5.2
+ 
+@@ -6,7 +7,7 @@
  # ownership (used by 'make install')
  
  user      := root
@@ -9,7 +15,16 @@
  
  
  # this WILL NOT WORK for you. only inhouse patched version of
-@@ -60,8 +60,6 @@
+@@ -27,7 +28,7 @@
+ 
+ # shared library- set to yes if you would like to build
+ 
+-buildshare := no
++buildshare := yes
+ 
+ 
+ # VCL library- set to yes if you would like to build
+@@ -60,8 +61,6 @@
  
  # paths
  
@@ -18,21 +33,48 @@
  bindir    := ${instdir}/bin
  libdir    := ${instdir}/lib
  hdir      := ${instdir}/include/sword
-@@ -80,7 +78,7 @@
+@@ -80,16 +79,16 @@
  WARNINGS  = -Wall -Wno-format -pedantic
  #WARNINGS += -Werror
  WARNINGS += -pedantic
 -CFLAGS    = -pipe $(WARNINGS) $(DEBUG)
-+CFLAGS   += -pipe $(WARNINGS) $(DEBUG)
++CFLAGS    += -pipe $(WARNINGS) $(DEBUG)
  
- CPPFLAGS  = -I${root}/include/ $(DEFINES)
+-CPPFLAGS  = -I${root}/include/ $(DEFINES)
++CPPFLAGS  += -I${root}/include/ $(DEFINES)
  ifeq ($(system),macosx)
-@@ -89,7 +87,7 @@
+ CPPFLAGS  += -I/System/Library/Frameworks/System.framework/Headers/
+ endif
  CPPFLAGS  += $(DEFINES)
  
  LFLAGS    = $(OPTIMIZE) $(DEBUG) -L${root}/lib/ 
 -LIBS      = -lsword -lstdc++
-+LIBS     += -lsword -lstdc++
++LIBS      += -lsword -lstdc++
  
  ifeq ($(zlib),no)
  CFLAGS += -DEXCLUDEZLIB
+@@ -97,9 +96,9 @@
+ LIBS += -lz
+ endif
+ 
+-LDFLAGS	= $(LFLAGS) $(LIBS)
++LDFLAGS	+= $(LFLAGS) $(LIBS)
+ 
+-DEFINES   = -D_GNU_SOURCE
++DEFINES   = -D_GNU_SOURCE -D_INSTDIR_="\"${instdir}\""
+ 
+ ifeq ($(profile),yes)
+ CFLAGS   += -pg
+@@ -256,9 +255,9 @@
+ ifneq (${confdir},)
+ 	@if [ ! -d ${confdir}/mods.d ]; then install -o ${user} -g ${group} -m a+rx,u+rxw -d ${confdir}/mods.d/ ; fi
+ 	@if [ ! -d ${confdir}/locales.d ]; then install -o ${user} -g ${group} -m a+rx,u+rxw -d ${confdir}/locales.d/ ; fi
+-	@echo "[Install]" > /etc/sword.conf
+-	@echo "DataPath=${confdir}" >> /etc/sword.conf
+-#	install -o ${user} -g ${group} -m a+r,u+rw samples/recommended/sword.conf /etc/
++	@echo "[Install]" > ${instdir}/etc/sword.conf
++	@echo "DataPath=${confdir}" >> ${instdir}/etc/sword.conf
++#	install -o ${user} -g ${group} -m a+r,u+rw samples/recommended/sword.conf ${instdir}/etc/
+ 	install -o ${user} -g ${group} -m a+r,u+rw ${modsconf} ${confdir}/mods.d/
+ 	install -o ${user} -g ${group} -m a+r,u+rw ${localesconf} ${confdir}/locales.d/
+ endif
diff -ruN misc/sword/files/sword.conf misc.new/sword/files/sword.conf
--- misc/sword/files/sword.conf	Tue Dec 11 10:36:33 2001
+++ misc.new/sword/files/sword.conf	Thu Jan  1 01:00:00 1970
@@ -1,2 +0,0 @@
-[Install]
-DataPath=/usr/local/share/sword/
diff -ruN misc/sword/pkg-plist misc.new/sword/pkg-plist
--- misc/sword/pkg-plist	Tue Dec 11 10:36:32 2001
+++ misc.new/sword/pkg-plist	Wed Dec 19 10:46:51 2001
@@ -5,10 +5,13 @@
 include/sword/cipherfil.h
 include/sword/defs.h
 include/sword/echomod.h
+include/sword/entriesblk.h
 include/sword/femain.h
 include/sword/filemgr.h
 include/sword/gbffootnotes.h
+include/sword/gbfheadings.h
 include/sword/gbfhtml.h
+include/sword/gbfmorph.h
 include/sword/gbfplain.h
 include/sword/gbfrtf.h
 include/sword/gbfstrongs.h
@@ -23,10 +26,13 @@
 include/sword/rawfiles.h
 include/sword/rawgbf.h
 include/sword/rawld.h
+include/sword/rawld4.h
 include/sword/rawstr.h
+include/sword/rawstr4.h
 include/sword/rawtext.h
 include/sword/rawverse.h
 include/sword/regex.h
+include/sword/roman.h
 include/sword/rtfhtml.h
 include/sword/rwphtml.h
 include/sword/rwprtf.h
@@ -47,20 +53,27 @@
 include/sword/swmacs.h
 include/sword/swmgr.h
 include/sword/swmodule.h
+include/sword/swobject.h
 include/sword/swtext.h
+include/sword/swunicod.h
 include/sword/swwinlog.h
 include/sword/tbdisp.h
 include/sword/thmlgbf.h
 include/sword/thmlhtml.h
+include/sword/thmlolb.h
 include/sword/thmlplain.h
 include/sword/thmlrtf.h
+include/sword/unicodertf.h
 include/sword/unixstr.h
+include/sword/untgz.h
 include/sword/utilconf.h
 include/sword/utilfuns.h
 include/sword/utilstr.h
 include/sword/versekey.h
 include/sword/zcom.h
+include/sword/zconf.h
 include/sword/zipcomprs.h
+include/sword/zlib.h
 include/sword/ztext.h
 include/sword/zverse.h
 lib/libsword.a

>Release-Note:
>Audit-Trail:
>Unformatted:

To Unsubscribe: send mail to majordomo@FreeBSD.org
with "unsubscribe freebsd-ports" in the body of the message




Want to link to this message? Use this URL: <https://mail-archive.FreeBSD.org/cgi/mid.cgi?200112201614.fBKGE7m15444>
diff -ruN misc/sword/files/patch-src::mgr::swmgr.cpp misc.new/sword/files/patch-src::mgr::swmgr.cpp
--- misc/sword/files/patch-src::mgr::swmgr.cpp	Tue Dec 11 10:36:33 2001
+++ misc.new/sword/files/patch-src::mgr::swmgr.cpp	Wed Dec 12 02:00:01 2001
@@ -1,33 +1,37 @@
---- src/mgr/swmgr.cpp.orig	Tue May 22 22:05:15 2001
-+++ src/mgr/swmgr.cpp	Tue May 22 22:05:53 2001
-@@ -263,25 +263,25 @@
+--- src/mgr/swmgr.cpp.org	Wed Dec 12 00:43:04 2001
++++ src/mgr/swmgr.cpp	Wed Dec 12 00:44:39 2001
+@@ -268,21 +268,21 @@
  	}
  
  
 -	// check for systemwide /etc/sword.conf
-+	// check for systemwide /usr/local/etc/sword.conf
++	// check for systemwide _INSTDIR_/etc/sword.conf
  
+ #ifndef __VISUALC__
  if (debug)
 -	cerr << "\nChecking for /etc/sword.conf...";
-+	cerr << "\nChecking for /usr/local/etc/sword.conf...";
++	cerr << "\nChecking for "_INSTDIR_"/etc/sword.conf...";
+ #endif
  
--	if ((fd = ::open("/etc/sword.conf", O_RDONLY)) > 0) {
-+	if ((fd = ::open("/usr/local/etc/sword.conf", O_RDONLY)) > 0) {
- 		::close(fd);
+-	if (!::access("/etc/sword.conf", 04)) {
++	if (!::access(_INSTDIR_"/etc/sword.conf", 04)) {
  
+ #ifndef __VISUALC__
  if (debug)
  	cerr << "found\n";
+ #endif
  
 -		SWConfig etcconf("/etc/sword.conf");
-+		SWConfig etcconf("/usr/local/etc/sword.conf");
++		SWConfig etcconf(_INSTDIR_"/etc/sword.conf");
  		if ((entry = etcconf.Sections["Install"].find("DataPath")) != etcconf.Sections["Install"].end()) {
  			path = (*entry).second;
  			if (((*entry).second.c_str()[strlen((*entry).second.c_str())-1] != '\\') && ((*entry).second.c_str()[strlen((*entry).second.c_str())-1] != '/'))
- 				path += "/";
+@@ -290,7 +290,7 @@
  
+ #ifndef __VISUALC__
  if (debug)
 -	cerr << "DataPath in /etc/sword.conf is set to: " << path;
-+	cerr << "DataPath in /usr/local/etc/sword.conf is set to: " << path;
++	cerr << "DataPath in "_INSTDIR_"/etc/sword.conf is set to: " << path;
+ #endif
  
- if (debug)
- 	cerr << "\nChecking for mods.conf in DataPath ";
+ #ifndef __VISUALC__